/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

/*
 * Parts of this code are copyright:
 * 
 * The contents of this file are subject to the Joram Public License, as defined
 * by the file JORAM_LICENSE.TXT
 * 
 * You may not use this file except in compliance with the License. You may
 * obtain a copy of the License on the Objectweb web site (www.objectweb.org).
 * 
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
 * the specific terms governing rights and limitations under the License.
 * 
 * The Original Code is Joram, including the java packages fr.dyade.aaa.agent,
 * fr.dyade.aaa.util, fr.dyade.aaa.ip, fr.dyade.aaa.mom, and fr.dyade.aaa.joram,
 * released May 24, 2000.
 * 
 * The Initial Developer of the Original Code is Dyade. The Original Code and
 * portions created by Dyade are Copyright Bull and Copyright INRIA. All Rights
 * Reserved.
 * 
 * The present code contributor is INRIA Rhone-Alpes.
 */

package org.objectweb.dream.aaa.agent;

import java.io.Serializable;

/**
 * Class Notification is the root of the notifications hierarchy. Every
 * notification's class has Notification as a superclass.
 */
public class Notification implements Serializable, Cloneable
{

  /**
   * Context of the notification.
   */
  private Object context;

  /**
   * Sets the context of the notification.
   * 
   * @param context the context of the notification.
   */
  public final void setContext(Object context)
  {
    this.context = context;
  }

  /**
   * Returns the context of the notification.
   * 
   * @return the context of the notification.
   */
  public final Object getContext()
  {
    return context;
  }

  /**
   * Returns a clone of this notification.
   * 
   * @return a clone of this notification.
   */
  public Object clone()
  {
    try
    {
      if (context != null)
      {
        Notification not = (Notification) super.clone();
        not.context = context;
        return not;
      }
      else
      {
        return super.clone();
      }
    }
    catch (CloneNotSupportedException e)
    {
      // this shouldn't happen, since we are Cloneable
      throw new InternalError();
    }
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString()
  {
    StringBuffer output = new StringBuffer();
    output.append("(");
    output.append(super.toString());
    output.append(",context=");
    output.append(context);
    output.append(")");
    return output.toString();
  }

}