/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.aaa.components;

import java.util.Map;

import org.objectweb.dream.AbstractComponent;
import org.objectweb.dream.Push;
import org.objectweb.dream.PushException;
import org.objectweb.dream.aaa.agent.AgentId;
import org.objectweb.dream.aaa.agent.Notification;
import org.objectweb.dream.aaa.agent.PushNotification;
import org.objectweb.dream.message.Message;
import org.objectweb.dream.message.manager.MessageManager;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;
import org.objectweb.util.monolog.api.BasicLevel;

/**
 * Simple component that extract notification, and agent informations from
 * message and delete it.
 */
public class MessageToNotifImpl extends AbstractComponent implements Push
{

  /**
   * The name of the client interface used to push the decalsulated
   * notifications.
   */
  public static final String OUT_PUSH_NOTIFICATION_ITF_NAME = "outPushNotification";

  private PushNotification   pushNotificationItf;
  private MessageManager     messageManagerItf;

  /**
   * @see Push#push(Message, Map)
   */
  public void push(Message message, Map context) throws PushException
  {
    AgentChunk agentChunk = (AgentChunk) message
        .getChunk(AgentChunk.DEFAULT_NAME);
    if (agentChunk == null)
    {
      logger.log(BasicLevel.ERROR, "Unable to find agent chunk named "
          + AgentChunk.DEFAULT_NAME + ". The message is dropped");
      return;
    }

    Notification notif = agentChunk.getAgentNotification();
    AgentId from = agentChunk.getAgentFrom();
    AgentId to = agentChunk.getAgentTo();
    messageManagerItf.deleteMessage(message);

    if (logger.isLoggable(BasicLevel.DEBUG))
    {
      logger.log(BasicLevel.DEBUG, "pushNotification from=" + from + ", to="
          + to + " notification " + notif);
    }

    pushNotificationItf.pushNotification(from, to, notif);
  }

  // ---------------------------------------------------------------------------
  // Implementation of BindingController interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{Push.OUT_PUSH_ITF_NAME, MessageManager.ITF_NAME};
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(String,
   *      Object)
   */
  public synchronized void bindFc(String clientItfName, Object serverItf)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException
  {
    if (clientItfName.equals(OUT_PUSH_NOTIFICATION_ITF_NAME))
    {
      pushNotificationItf = (PushNotification) serverItf;
    }
    else if (clientItfName.equals(MessageManager.ITF_NAME))
    {
      messageManagerItf = (MessageManager) serverItf;
    }
    super.bindFc(clientItfName, serverItf);
  }

}