/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.aaa.components.conf;

/**
 * Component interface provided by agnet server configuration component.
 */
public interface AgentServerConfiguration
{

  /** The default name for interfaces of this type. */
  String DEFAULT_NAME = "agent-server-configuration";

  /**
   * Returns the repository description object for the specified repository
   * name. Returns <code>null</code> if no registry with the specified name is
   * defined in this server.
   * 
   * @param repositoryName a repository name.
   * @return the repository description object for the specified repository
   *         name.
   */
  RepositoryDesc getRepositoryDesc(String repositoryName);

  /**
   * Returns the repository description object for the specified repository
   * identifier. Returns <code>null</code> if no registry with the specified
   * identifier is defined in this server.
   * 
   * @param repositoryId a repository identifer.
   * @return the repository description object for the specified repository
   *         name.
   */
  RepositoryDesc getRepositoryDesc(short repositoryId);

  /**
   * Returns the description object of the default repository of the local
   * server.
   * 
   * @return the description object of the default repository of the local
   *         server.
   */
  RepositoryDesc getDefaultRepositoryDesc();

  /**
   * Returns the description of the local network for the specified domain name.
   * Returns <code>null</code> if no network for the specified domain if
   * defined in this server.
   * 
   * @param domainName a domain name
   * @return the description of the local network for the specified domain name.
   */
  NetworkDesc getNetworkDesc(String domainName);

  /**
   * Returns the repositories accessible throught the message consumer with the
   * specified name. If returns <code>null</code>, every repositories are
   * accessible throught the message consumer.
   * 
   * @param messageConsumerName the name of a local engine or the name of a
   *          domain.
   * @return an array containing every accessible repositories.
   * @throws IllegalArgumentException if the specified message consumer is
   *           unknown (i.e. is neither a domain name of a local network, nor a
   *           local repository name).
   */
  short[] getAccessibleRepositories(String messageConsumerName);
}