/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): Vivien Quema
 */

package org.objectweb.dream.channel;

import java.io.IOException;
import java.io.ObjectOutputStream;
import java.net.Socket;
import java.util.Map;

import org.objectweb.dream.PushException;
import org.objectweb.dream.message.ExtensibleMessage;
import org.objectweb.dream.message.Message;
import org.objectweb.util.monolog.api.BasicLevel;

/**
 * Basic implementation of a ChannelOut component. TODO improve
 */
public class BasicTCPChannelOutImpl extends AbstractTCPChannelOutImpl
    implements
      MultiDestinationChannelOutAttributeController
{

  protected String chunkName = IPChannelDestinationChunk.DEFAULT_NAME;

  // ---------------------------------------------------------------------------
  // Implementation of the Push interface
  // ---------------------------------------------------------------------------

  /**
   * @see org.objectweb.dream.Push#push(Message, Map)
   */
  public void push(Message message, Map context) throws PushException
  {
    IPChannelDestinationChunk destination = (IPChannelDestinationChunk) message
        .getChunk(chunkName);
    // try to remove chunk
    if (message instanceof ExtensibleMessage)
    {
      messageManagerItf.deleteChunk(((ExtensibleMessage) message)
          .removeChunk(chunkName));
    }

    try
    {
      if (logger.isLoggable(BasicLevel.DEBUG))
      {
        logger.log(BasicLevel.DEBUG, "try to send message -> " + message);
      }
      Socket sock = connectSocket(destination.getChannelDestinationAddr(),
          destination.getChannelDestinationPort());
      ObjectOutputStream oos = new ObjectOutputStream(sock.getOutputStream());
      logger.log(BasicLevel.DEBUG, "write message");

      messageCodecItf.encode(oos, message);

      receiveAck(sock);
      messageManagerItf.deleteMessage(message);

      oos.close();
      sock.close();
    }
    catch (IOException e)
    {
      throw new PushException(e);
    }
  }

  // ---------------------------------------------------------------------------
  // Implementation of the MultiDestinationChannelOutAttributeController
  // interface
  // ---------------------------------------------------------------------------

  /**
   * @see MultiDestinationChannelOutAttributeController#getDestinationChunkName()
   */
  public String getDestinationChunkName()
  {
    return chunkName;
  }

  /**
   * @see MultiDestinationChannelOutAttributeController#setDestinationChunkName(String)
   */
  public void setDestinationChunkName(String name)
  {
    chunkName = name;
  }

  // ---------------------------------------------------------------------------
  // Utility methods
  // ---------------------------------------------------------------------------

  /**
   * Does not do anything.
   * 
   * @param sock the socket to be used.
   * @throws IOException if an error occurs.
   */
  protected void receiveAck(Socket sock) throws IOException
  {
  }
}