/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact : dream@objectweb.org
 *
 * Initial developer(s): Vivien Quema
 * Contributor(s): 
 */

package org.objectweb.dream.control.activity.scheduler;

import org.objectweb.fractal.api.Component;
import org.objectweb.fractal.api.control.IllegalContentException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;

/**
 * A control interface to manage schedulers.
 */
public interface SchedulerManagerController
{

  /**
   * Registers a new scheduler.
   * 
   * @param scheduler the scheduler to be registered.
   * @throws IllegalContentException if a content error occurs.
   * @throws IllegalLifeCycleException if a lifecycle error occurs.
   */
  void registerScheduler(Component scheduler) throws IllegalContentException,
      IllegalLifeCycleException;

  /**
   * Unregisters the specified scheduler.
   * 
   * @param scheduler the scheduler to be removed.
   * @throws IllegalContentException if a content error occurs.
   * @throws IllegalLifeCycleException if a lifecycle error occurs.
   */
  void unregisterScheduler(Component scheduler) throws IllegalContentException,
      IllegalLifeCycleException;

  /**
   * Returns the schedulers that have been registered.
   * 
   * @return the schedulers that have been registered.
   */
  Component[] getSchedulers();

}