/**
 * DREAM Copyright (C) 2003 2004 INRIA Rhone-Alpes
 * 
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option) any
 * later version.
 * 
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation, Inc.,
 * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 * 
 * Contact: dream@objectweb.org
 * 
 * Initial developer(s): Matthieu Leclercq Contributor(s):
 */

package org.objectweb.dream.control.activity.task.thread;

import org.objectweb.fractal.api.control.AttributeController;

/**
 * Attribute controller for thread pool component.
 */
public interface ThreadPoolAttributeController extends AttributeController
{

  /**
   * The default timeout.
   * 
   * @see #setWaitTimeout(long)
   */
  long DEFAULT_WAIT_TIMEOUT = 2000;

  /**
   * Sets the capacity of the pool. The capacity of the pool is the maximum
   * number of currently executing threads. If the capacity is decreased, none
   * of the threads is stopped, so the number of executing threads may
   * temporarily exced the capacity.
   * 
   * @param i the capacity of the pool.
   */
  void setCapacity(int i);

  /**
   * Returns the capacity of the pool.
   * 
   * @return the capacity of the pool.
   */
  int getCapacity();

  /**
   * Sets the timeout while a "dying" thread can be "reactivated" and reused,
   * rather than create a new thread.
   * 
   * @param millis timeout in millisecond.
   */
  void setWaitTimeout(long millis);

  /**
   * Returns the timeout while "dying" thread can be "reactivated".
   * 
   * @return timeout in millisecond.
   */
  long getWaitTimeout();
}