/**
 * DREAM
 * Copyright (C) 2003 2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.xml;

import org.apache.xerces.parsers.SAXParser;
import org.objectweb.fractal.api.NoSuchInterfaceException;
import org.objectweb.fractal.api.control.BindingController;
import org.objectweb.fractal.api.control.IllegalBindingException;
import org.objectweb.fractal.api.control.IllegalLifeCycleException;
import org.xml.sax.ContentHandler;

/**
 * Extention of the {@link org.apache.xerces.parsers.SAXParser}to give it a
 * Fractal component behaviour. This Fractal component has a server interface of
 * type {@link org.xml.sax.XMLReader}and a client interface of type
 * {@link org.xml.sax.ContentHandler}.
 */
public class SaxXercesParser extends SAXParser implements BindingController
{

  /**
   * The name of the {@link ContentHandler}client interface.
   */
  public static final String CONTENT_HANDLER_ITF_NAME = "content-handler";

  /**
   * @see org.objectweb.fractal.api.control.BindingController#listFc()
   */
  public String[] listFc()
  {
    return new String[]{CONTENT_HANDLER_ITF_NAME};
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#lookupFc(java.lang.String)
   */
  public Object lookupFc(String clientItfName) throws NoSuchInterfaceException
  {
    if (clientItfName.equals(CONTENT_HANDLER_ITF_NAME))
    {
      return getContentHandler();
    }
    return null;
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#bindFc(java.lang.String,
   *      java.lang.Object)
   */
  public void bindFc(String clientItfName, Object serverItf)
      throws NoSuchInterfaceException, IllegalBindingException,
      IllegalLifeCycleException
  {
    if (clientItfName.equals(CONTENT_HANDLER_ITF_NAME))
    {
      setContentHandler((ContentHandler) serverItf);
    }
  }

  /**
   * @see org.objectweb.fractal.api.control.BindingController#unbindFc(java.lang.String)
   */
  public void unbindFc(String clientItfName) throws NoSuchInterfaceException,
      IllegalBindingException, IllegalLifeCycleException
  {
    if (clientItfName.equals(CONTENT_HANDLER_ITF_NAME))
    {
      setContentHandler(null);
    }
  }

}